==> xl-react-components-0.21.15.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/map-value-input.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import XlReactWidgetRevealPasswordIcon
    from '../../xl-react-widget/xl-react-widget-reveal-password-icon/xl-react-widget-reveal-password-icon';
import {blurFieldOnSubmit} from '../input/input-service';
import {getInputType}
    from '../../xl-react-widget/xl-react-widget-reveal-password-icon/xl-react-widget-reveal-password-utils';
import {isTextType} from './xl-react-dip-map-string-string-constants';

export class MapValueInput extends Component {
    static propTypes = {
        disabled: PropTypes.bool.isRequired,
        handleFocus: PropTypes.func,
        handleOnPasswordPaste: PropTypes.func.isRequired,
        handleRemoveKey: PropTypes.func.isRequired,
        handleRevealPassword: PropTypes.func.isRequired,
        handleValueChange: PropTypes.func.isRequired,
        inputType: PropTypes.string.isRequired,
        itemKey: PropTypes.string.isRequired,
        revealPassword: PropTypes.bool.isRequired,
        revealPasswordIconVisible: PropTypes.bool.isRequired,
        shouldFocus: PropTypes.bool.isRequired,
        value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired
    };

    componentDidMount() {
        if (this.props.shouldFocus && this.inputField) {
            this.inputField.focus({preventScroll: true});
        }
    }

    handleChange = ({target: {value}}) => {
        const {handleValueChange, itemKey} = this.props;
        handleValueChange(itemKey, value);
    };

    handleRemoveKey = () => {
        const {handleRemoveKey, itemKey} = this.props;
        handleRemoveKey(itemKey);
    };

    handleKeyDown = (event) => {
        blurFieldOnSubmit(this.inputField, event);
    };

    assignInputValueRef = (input) => {
        this.inputField = input;
    };

    shouldShowIcon = () => {
        const {value, inputType, revealPasswordIconVisible} = this.props;
        return value && revealPasswordIconVisible && inputType === 'password';
    };

    getTitle = (inputType, value) => isTextType(inputType) ? value : null;

    getInputComponent = () => {
        const {
            disabled,
            handleFocus,
            handleOnPasswordPaste,
            inputType,
            revealPassword,
            itemKey,
            value
        } = this.props;

        return inputType === 'password' ?
            <input
                onChange={this.handleChange}
                onFocus={handleFocus(itemKey)}
                onKeyDown={this.handleKeyDown}
                onPaste={handleOnPasswordPaste(itemKey)}
                readOnly={disabled}
                ref={this.assignInputValueRef}
                title={this.getTitle(inputType, value)}
                type={getInputType(inputType, revealPassword)}
                value={value}
            /> :
            <textarea
                onChange={this.handleChange}
                onFocus={handleFocus(itemKey)}
                onKeyDown={this.handleKeyDown}
                readOnly={disabled}
                ref={this.assignInputValueRef}
                title={this.getTitle(inputType, value)}
                value={value}
            />;
    };

    render() {
        const {
            disabled,
            handleRevealPassword,
            itemKey,
            revealPassword
        } = this.props;

        const closeBtn = <i
            className="xl-icon close-icon"
            onClick={this.handleRemoveKey}
        />;
        return <div className="value-div" key={itemKey}>
            {this.getInputComponent()}
            <XlReactWidgetRevealPasswordIcon
                handleRevealPassword={handleRevealPassword(itemKey)}
                isPasswordRevealed={revealPassword}
                showIconCondition={this.shouldShowIcon}
            />
            {disabled ? null : closeBtn}
        </div>;
    }
}

==> xl-react-components-0.21.16.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/map-value-input.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import XlReactWidgetRevealPasswordIcon
    from '../../xl-react-widget/xl-react-widget-reveal-password-icon/xl-react-widget-reveal-password-icon';
import {blurFieldOnSubmit} from '../input/input-service';
import {getInputType}
    from '../../xl-react-widget/xl-react-widget-reveal-password-icon/xl-react-widget-reveal-password-utils';
import {isTextType} from './xl-react-dip-map-string-string-constants';

export class MapValueInput extends Component {
    static propTypes = {
        disabled: PropTypes.bool.isRequired,
        editedValue: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
        handleFocus: PropTypes.func,
        handleOnPasswordPaste: PropTypes.func.isRequired,
        handleRemoveKey: PropTypes.func.isRequired,
        handleRevealPassword: PropTypes.func.isRequired,
        handleValueBlur: PropTypes.func.isRequired,
        handleValueChange: PropTypes.func.isRequired,
        inputType: PropTypes.string.isRequired,
        itemKey: PropTypes.string.isRequired,
        revealPassword: PropTypes.bool.isRequired,
        revealPasswordIconVisible: PropTypes.bool.isRequired,
        shouldFocus: PropTypes.bool.isRequired,
        value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired
    };

    componentDidMount() {
        if (this.props.shouldFocus && this.inputField) {
            this.inputField.focus({preventScroll: true});
            this.props.handleValueChange(this.props.editedValue);
        }
    }

    handleChange = ({target: {value}}) => {
        this.props.handleValueChange(value);
    };

    handleRemoveKey = () => {
        const {handleRemoveKey, itemKey} = this.props;
        handleRemoveKey(itemKey);
    };

    handleKeyDown = (event) => {
        blurFieldOnSubmit(this.inputField, event);
    };

    assignInputValueRef = (input) => {
        this.inputField = input;
    };

    shouldShowIcon = () => {
        const {editedValue, inputType, revealPasswordIconVisible, shouldFocus, value} = this.props;
        const shownValue = shouldFocus ? editedValue : value;
        return shownValue && revealPasswordIconVisible && inputType === 'password';
    };

    getTitle = (inputType, value) => isTextType(inputType) ? value : null;

    getInputComponent = () => {
        const {
            disabled,
            editedValue,
            handleFocus,
            handleOnPasswordPaste,
            inputType,
            revealPassword,
            shouldFocus,
            itemKey,
            value
        } = this.props;

        const shownValue = shouldFocus ? editedValue : value;
        return inputType === 'password' ?
            <input
                onBlur={this.props.handleValueBlur}
                onChange={this.handleChange}
                onFocus={handleFocus(itemKey)}
                onKeyDown={this.handleKeyDown}
                onPaste={handleOnPasswordPaste(itemKey)}
                readOnly={disabled}
                ref={this.assignInputValueRef}
                title={this.getTitle(inputType, shownValue)}
                type={getInputType(inputType, revealPassword)}
                value={shownValue}
            /> :
            <textarea
                onBlur={this.props.handleValueBlur}
                onChange={this.handleChange}
                onFocus={handleFocus(itemKey)}
                onKeyDown={this.handleKeyDown}
                readOnly={disabled}
                ref={this.assignInputValueRef}
                title={this.getTitle(inputType, shownValue)}
                value={shownValue}
            />;
    };

    render() {
        const {
            disabled,
            handleRevealPassword,
            itemKey,
            revealPassword
        } = this.props;

        const closeBtn = <i
            className="xl-icon close-icon"
            onClick={this.handleRemoveKey}
        />;
        return <div className="value-div" key={itemKey}>
            {this.getInputComponent()}
            <XlReactWidgetRevealPasswordIcon
                handleRevealPassword={handleRevealPassword(itemKey)}
                isPasswordRevealed={revealPassword}
                showIconCondition={this.shouldShowIcon}
            />
            {disabled ? null : closeBtn}
        </div>;
    }
}
